@@ -43,10 +43,6 @@ enum
 	LAST_SIGNAL
 };
 
-static void gnome_property_box_class_init     (GnomePropertyBoxClass *klass);
-static void gnome_property_box_instance_init  (GnomePropertyBox *property_box);
-static void gnome_property_box_destroy        (GtkObject *object);
-
 /*
  * These four are called from dialog_clicked_cb(), depending
  * on which button was clicked.
@@ -62,38 +58,34 @@ static void dialog_clicked_cb (GnomeDialog * dialog, gint button,
 static gint property_box_signals [LAST_SIGNAL] = { 0 };
 
 GNOME_CLASS_BOILERPLATE(GnomePropertyBox, gnome_property_box,
-			GnomeDialog, gnome_dialog, GNOME_TYPE_DIALOG);
+			GnomeDialog, GNOME_TYPE_DIALOG);
 static void
 gnome_property_box_class_init (GnomePropertyBoxClass *klass)
 {
 	GtkObjectClass *object_class;
-	GtkWidgetClass *widget_class;
-	GtkWindowClass *window_class;
 
 	object_class = (GtkObjectClass*) klass;
-	widget_class = (GtkWidgetClass*) klass;
-	window_class = (GtkWindowClass*) klass;
 
-	object_class->destroy = gnome_property_box_destroy;
-
-	parent_class = gtk_type_class (GNOME_TYPE_DIALOG);
+	parent_class = g_type_class_peek_parent (klass);
 
 	property_box_signals[APPLY] =
-		gtk_signal_new ("apply",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePropertyBoxClass,
-						   apply),
-				gtk_marshal_VOID__INT,
-				GTK_TYPE_NONE, 1, GTK_TYPE_INT);
+		g_signal_new ("apply",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GnomePropertyBoxClass, apply),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__INT,
+			      G_TYPE_NONE, 1,
+			      G_TYPE_INT);
 	property_box_signals[HELP] =
-		gtk_signal_new ("help",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePropertyBoxClass,
-						   help),
-				gtk_marshal_VOID__INT,
-				GTK_TYPE_NONE, 1, GTK_TYPE_INT);
+		g_signal_new ("help",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GnomePropertyBoxClass, help),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__INT,
+			      G_TYPE_NONE, 1,
+			      G_TYPE_INT);
 
 	klass->apply = NULL;
 	klass->help = NULL;
@@ -106,47 +98,33 @@ gnome_property_box_instance_init (GnomePropertyBox *property_box)
 
 	property_box->notebook = gtk_notebook_new ();
 
-	/* FIXME!
-	* if (gnome_preferences_get_property_box_apply ()){ */
-		gnome_dialog_append_buttons (GNOME_DIALOG (property_box),
-					     GNOME_STOCK_BUTTON_OK,
-					     GNOME_STOCK_BUTTON_APPLY,
-					     GNOME_STOCK_BUTTON_CLOSE,
-					     GNOME_STOCK_BUTTON_HELP,
-					     NULL);
-	/*} else {
-		gnome_dialog_append_buttons (GNOME_DIALOG (property_box),
-					     GNOME_STOCK_BUTTON_OK,
-					     GNOME_STOCK_BUTTON_CANCEL,
-					     GNOME_STOCK_BUTTON_HELP,
-					     NULL);
-	} */
+	gnome_dialog_append_buttons (GNOME_DIALOG (property_box),
+				     GNOME_STOCK_BUTTON_HELP,
+				     GNOME_STOCK_BUTTON_APPLY,
+				     GNOME_STOCK_BUTTON_CLOSE,
+				     GNOME_STOCK_BUTTON_OK,
+				     NULL);
 
-	gnome_dialog_set_default (GNOME_DIALOG (property_box), 0);
+	gnome_dialog_set_default (GNOME_DIALOG (property_box), 3);
 
 	/* This is sort of unattractive */
 
 	button_list = GNOME_DIALOG(property_box)->buttons;
 
-	property_box->ok_button = GTK_WIDGET(button_list->data);
+	property_box->help_button = GTK_WIDGET(button_list->data);
 	button_list = button_list->next;
-	
-	/* FIXME!
-	if (gnome_preferences_get_property_box_apply ()){ */
-		property_box->apply_button = GTK_WIDGET(button_list->data);
-		button_list = button_list->next;
-		gtk_widget_set_sensitive (property_box->apply_button, FALSE);
-	/*} else
-		property_box->apply_button = 0; */
-	
+
+	property_box->apply_button = GTK_WIDGET(button_list->data);
+	button_list = button_list->next;
+	gtk_widget_set_sensitive (property_box->apply_button, FALSE);
+
 	property_box->cancel_button = GTK_WIDGET(button_list->data);
 	button_list = button_list->next;
-	property_box->help_button = GTK_WIDGET(button_list->data);
-	
+	property_box->ok_button = GTK_WIDGET(button_list->data);
 
-	gtk_signal_connect ( GTK_OBJECT(property_box), "clicked",
-			     GTK_SIGNAL_FUNC(dialog_clicked_cb),
-			     NULL );
+	g_signal_connect (property_box, "clicked",
+			  G_CALLBACK(dialog_clicked_cb),
+			  NULL);
 
 	gtk_box_pack_start (GTK_BOX(GNOME_DIALOG(property_box)->vbox),
 			    property_box->notebook,
@@ -155,17 +133,6 @@ gnome_property_box_instance_init (GnomePropertyBox *property_box)
 	gtk_widget_show (property_box->notebook);
 }
 
-static void
-gnome_property_box_destroy (GtkObject *object)
-{
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (GNOME_IS_PROPERTY_BOX (object));
-	/* remember, destroy can be run multiple times! */
-
-	if(GTK_OBJECT_CLASS (parent_class)->destroy)
-		GTK_OBJECT_CLASS (parent_class)->destroy (object);
-}
-
 /**
  * gnome_property_box_new: [constructor]
  *
@@ -181,7 +148,7 @@ gnome_property_box_destroy (GtkObject *object)
 GtkWidget *
 gnome_property_box_new (void)
 {
-	return gtk_type_new (GNOME_TYPE_PROPERTY_BOX);
+	return g_object_new (GNOME_TYPE_PROPERTY_BOX, NULL);
 }
 
 static void
@@ -194,18 +161,16 @@ dialog_clicked_cb(GnomeDialog * dialog, gint button, gpointer data)
 
 	g_return_if_fail(dialog != NULL);
 	g_return_if_fail(GNOME_IS_PROPERTY_BOX(dialog));
-        
+
 	pbox = GNOME_PROPERTY_BOX (dialog);
 
-	cur_page_no = gtk_notebook_current_page (GTK_NOTEBOOK (pbox->notebook));
+	cur_page_no = gtk_notebook_get_current_page (GTK_NOTEBOOK (pbox->notebook));
         if (cur_page_no >= 0) {
 	    gint page_no = 0;
-	    GtkWidget *page;
 
 	    page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (pbox->notebook), 0);
 	    while (page != NULL) {
-		dirty = GPOINTER_TO_INT(gtk_object_get_data (GTK_OBJECT (page),
-							     GNOME_PROPERTY_BOX_DIRTY));
+		dirty = GPOINTER_TO_INT(g_object_get_data (G_OBJECT (page), GNOME_PROPERTY_BOX_DIRTY));
 		if (dirty)
 		    break;
 
@@ -216,45 +181,26 @@ dialog_clicked_cb(GnomeDialog * dialog, gint button, gpointer data)
                 page = NULL;
                 dirty = FALSE;
         }
-                
-	/* Choose which style we did */
-	if (pbox->apply_button){
-		switch(button) {
-		case 0:
-			if (dirty)
-				apply_and_close (GNOME_PROPERTY_BOX (dialog));
-			else
-				just_close (GNOME_PROPERTY_BOX (dialog));
-			break;
-		case 1:
-			global_apply (GNOME_PROPERTY_BOX (dialog));
-			break;
-		case 2:
+
+	switch(button) {
+	case 0:
+		help (GNOME_PROPERTY_BOX (dialog));
+		break;
+	case 1:
+		global_apply (GNOME_PROPERTY_BOX (dialog));
+		break;
+	case 2:
+		just_close (GNOME_PROPERTY_BOX (dialog));
+		break;
+	case 3:
+		if (dirty)
+			apply_and_close (GNOME_PROPERTY_BOX (dialog));
+		else
 			just_close (GNOME_PROPERTY_BOX (dialog));
-			break;
-		case 3:
-			help (GNOME_PROPERTY_BOX (dialog));
-			break;
-		default:
-			g_assert_not_reached();
-		}
-	} else {
-		switch(button) {
-		case 0:
-			if (dirty)
-				apply_and_close (GNOME_PROPERTY_BOX (dialog));
-			else
-				just_close (GNOME_PROPERTY_BOX (dialog));
-			break;
-		case 1:
-			just_close (GNOME_PROPERTY_BOX (dialog));
-			break;
-		case 2:
-			help (GNOME_PROPERTY_BOX (dialog));
-			break;
-		default:
-			g_assert_not_reached();
-		}
+		break;
+
+	default:
+		g_assert_not_reached();
 	}
 }
 
@@ -286,14 +232,12 @@ gnome_property_box_changed (GnomePropertyBox *property_box)
 	cur_page_no = gtk_notebook_get_current_page (GTK_NOTEBOOK (property_box->notebook));
 	if (cur_page_no < 0)
 	    return;
-	
+
 	page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (property_box->notebook),
 					  cur_page_no);
 	g_assert (page != NULL);
-	
-	gtk_object_set_data(GTK_OBJECT(page),
-			    GNOME_PROPERTY_BOX_DIRTY,
-			    GINT_TO_POINTER(1));
+
+	g_object_set_data(G_OBJECT(page), GNOME_PROPERTY_BOX_DIRTY, GINT_TO_POINTER(1));
 
 	set_sensitive (property_box, 1);
 }
@@ -301,7 +245,7 @@ gnome_property_box_changed (GnomePropertyBox *property_box)
 /**
  * gnome_property_box_set_modified:
  * @property_box: The GnomePropertyBox that contains the changed data
- * @state:        The state.  TRUE means modified, FALSE means unmodified.
+ * @state:        The state. %TRUE means modified, %FALSE means unmodified.
  *
  * This sets the modified flag of the GnomePropertyBox to the value in @state.
  * Affects whether the OK/Apply buttons are sensitive.
@@ -316,23 +260,27 @@ gnome_property_box_set_modified (GnomePropertyBox *property_box, gboolean state)
 	g_return_if_fail (GNOME_IS_PROPERTY_BOX (property_box));
 	g_return_if_fail (property_box->notebook);
 	g_return_if_fail (GTK_NOTEBOOK (property_box->notebook)->cur_page);
-	
+
 	cur_page_no = gtk_notebook_get_current_page (GTK_NOTEBOOK (property_box->notebook));
 	if (cur_page_no < 0)
 	    return;
-	
+
 	page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (property_box->notebook),
 					  cur_page_no);
 	g_assert (page != NULL);
-	
-	gtk_object_set_data(GTK_OBJECT(page),
-			    GNOME_PROPERTY_BOX_DIRTY,
-			    GINT_TO_POINTER(state ? 1 : 0));
+
+	g_object_set_data(G_OBJECT(page), GNOME_PROPERTY_BOX_DIRTY, GINT_TO_POINTER(state ? 1 : 0));
 
 	set_sensitive (property_box, state);
 }
 
-/* Deprecated */
+/**
+ * gnome_property_box_set_state:
+ * @property_box: The GnomePropertyBox that contains the changed data
+ * @state: The state. %TRUE means modified, %FALSE means unmodified.
+ *
+ * An alias for  gnome_property_box_set_modified().
+ */
 void
 gnome_property_box_set_state (GnomePropertyBox *property_box, gboolean state)
 {
@@ -353,13 +301,10 @@ global_apply (GnomePropertyBox *property_box)
 	n = 0;
 	page = gtk_notebook_get_nth_page(GTK_NOTEBOOK(property_box->notebook), n);
 	while (page != NULL) {
-		if (gtk_object_get_data(GTK_OBJECT(page),
-					GNOME_PROPERTY_BOX_DIRTY)) {
-			gtk_signal_emit (GTK_OBJECT (property_box),
-					 property_box_signals[APPLY], n);
-			gtk_object_set_data(GTK_OBJECT(page),
-					    GNOME_PROPERTY_BOX_DIRTY,
-					    GINT_TO_POINTER(0));
+		if (g_object_get_data(G_OBJECT(page), GNOME_PROPERTY_BOX_DIRTY)) {
+			g_signal_emit (property_box, property_box_signals[APPLY], 0,
+				       n);
+			g_object_set_data(G_OBJECT(page), GNOME_PROPERTY_BOX_DIRTY, GINT_TO_POINTER(0));
 		}
 
 		page = gtk_notebook_get_nth_page(GTK_NOTEBOOK(property_box->notebook), ++n);
@@ -367,8 +312,8 @@ global_apply (GnomePropertyBox *property_box)
 
 	/* Emit an apply signal with a button of -1.  This means we
 	   just finished a global apply.  Is this a hack?  */
-	gtk_signal_emit (GTK_OBJECT (property_box),
-			 property_box_signals[APPLY], (gint) -1);
+	g_signal_emit (property_box, property_box_signals[APPLY], 0,
+		       (gint) -1);
 
 	/* Doesn't matter which item we use. */
 	set_sensitive (property_box, 0);
@@ -379,10 +324,9 @@ help (GnomePropertyBox *property_box)
 {
 	gint page;
 
-	page =
-	  gtk_notebook_get_current_page (GTK_NOTEBOOK (property_box->notebook));
-	gtk_signal_emit (GTK_OBJECT (property_box), property_box_signals[HELP],
-			 page);
+	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (property_box->notebook));
+	g_signal_emit (property_box, property_box_signals[HELP], 0,
+		       page);
 }
 
 static void
@@ -420,7 +364,7 @@ gnome_property_box_append_page (GnomePropertyBox *property_box,
 	g_return_val_if_fail (GTK_IS_WIDGET (child), -1);
 	g_return_val_if_fail (tab_label != NULL, -1);
 	g_return_val_if_fail (GTK_IS_WIDGET (tab_label), -1);
-		
+
 	gtk_notebook_append_page (GTK_NOTEBOOK (property_box->notebook),
 				  child, tab_label);
 
